@@ -1206,6 +1206,7 @@ int e1inp_ipa_bts_rsl_connect_n(struct e1inp_line *line,
 /* Close the underlying IPA TCP socket of an RSL link */
 int e1inp_ipa_bts_rsl_close_n(struct e1inp_line *line, uint8_t trx_nr)
 {
+	struct ipa_client_conn *conn;
 	struct ipaccess_line *il;
 	struct e1inp_ts *e1i_ts;
 
@@ -1222,9 +1223,10 @@ int e1inp_ipa_bts_rsl_close_n(struct e1inp_line *line, uint8_t trx_nr)
 	e1i_ts = e1inp_line_ipa_rsl_ts(line, trx_nr);
 	ipaccess_keepalive_fsm_cleanup(e1i_ts);
 
-	if (il->ipa_cli[1 + trx_nr]) {
-		ipa_client_conn_close(il->ipa_cli[1 + trx_nr]);
-		ipa_client_conn_destroy(il->ipa_cli[1 + trx_nr]);
+	conn = il->ipa_cli[1 + trx_nr];
+	if (conn != NULL) {
+		ipa_client_conn_close(conn);
+		ipa_client_conn_destroy(conn);
 		il->ipa_cli[1 + trx_nr] = NULL;
 	}
 	return 0;
